@@ -55,6 +55,7 @@ module.exports = {
         "segments/argocd",
         "segments/aws",
         "segments/az",
+        "segments/azd",
         "segments/azfunc",
         "segments/battery",
         "segments/bazel",
@@ -137,6 +138,7 @@ module.exports = {
         "segments/withings",
         "segments/winreg",
         "segments/xmake",
+        "segments/yarn",
         "segments/ytm",
       ],
     },
